==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/es-MX/mail.php <==
<?php

return array(
    'a_user_canceled' => 'El usuario ha cancelado el item solicitado en la pagina Web',
    'a_user_requested' => 'Un usuario a solicitado un item en la pagina Web',
    'accessory_name' => 'Nombre de accesorio:',
    'additional_notes' => 'Notas adicionales:',
    'admin_has_created' => 'Un administrador ha creado una cuenta para ti en la web :web.',
    'asset' => 'Activo:',
    'asset_name' => 'Nombre del activo:',
    'asset_requested' => 'Activo solicitado',
    'asset_tag' => 'Etiqueta de activo:',
    'assigned_to' => 'Asignado a',
    'best_regards' => 'Cordialmente,',
    'canceled' => 'Cancelado:',
    'checkin_date' => 'Fecha de entrada:',
    'checkout_date' => 'Fecha de salida:',
    'click_to_confirm' => 'Por favor, pulsa en el siguiente enlace para verificar tu cuenta de :web:',
    'click_on_the_link_accessory' => 'Haga clic en el enlace en la parte inferior para confirmar que ha recibido el accesorio.',
    'click_on_the_link_asset' => 'Haga clic en el enlace en la parte inferior para confirmar que ha recibido el activo.',
    'Confirm_Asset_Checkin' => 'Confirmar devolución del activo',
    'Confirm_Accessory_Checkin' => 'Confirmar devolución del accesorio',
    'Confirm_accessory_delivery' => 'Confirma entrega de accesorio',
    'Confirm_license_delivery' => 'Confirma entrega de licencia',
    'Confirm_asset_delivery' => 'Confirma entrega de activo',
    'Confirm_consumable_delivery' => 'Confirma entrega de consumible',
    'current_QTY' => 'Cantidad actual',
    'Days' => 'Días',
    'days' => 'Días',
    'expecting_checkin_date' => 'Fecha de devolución prevista:',
    'expires' => 'Expira',
    'Expiring_Assets_Report' => 'Informe de activos que expiran.',
    'Expiring_Licenses_Report' => 'Informe de licencias que expiran.',
    'hello' => 'Hola',
    'hi' => 'Hola',
    'i_have_read' => 'Ha leído y aceptado los términos de uso y he recibido este artículo.',
    'item' => 'Articulo:',
    'Item_Request_Canceled' => 'Solicitud de cancelación de requerimiento',
    'Item_Requested' => 'Artículo solicitado',
    'link_to_update_password' => 'Haga clic en el siguiente enlace para actualizar su: contraseña de la web:',
    'login_first_admin' => 'Inicie sesión en su nueva instalación de Snipe-IT con las credenciales siguientes:',
    'login' => 'Entrar:',
    'Low_Inventory_Report' => 'Reporte de inventario bajo',
    'min_QTY' => 'Cantidad mínima',
    'name' => 'Nombre',
    'new_item_checked' => 'Un nuevo artículo se ha extraído bajo su nombre, los detalles están a continuación.',
    'password' => 'Contraseña:',
    'password_reset' => 'Reiniciar la contraseña',

    'read_the_terms' => 'Por favor lea las condiciones de uso a continuación.',
    'read_the_terms_and_click' => 'Por favor lea los términos de uso abajo y haga clic en el enlace en la parte inferior para confirmar que leído y acepta los términos de uso y han recibido el activo.',
    'requested' => 'Solicitado:',
    'reset_link' => 'Tu enlace de restablecimiento de contraseña',
    'reset_password' => 'Haga Clic aquí para restablecer su contraseña:',
    'serial' => 'Serial',
    'supplier' => 'Proveedor',
    'tag' => 'Etiqueta',
    'test_email' => 'Email de prueba de Snipe-IT',
    'test_mail_text' => 'Esto es una prueba desde el sistema de gestión de activos de Snipe-IT. Si tienes esto, correo está funcionando :)',
    'the_following_item' => 'El siguiente artículo ha sido devuelto: ',
    'low_inventory_alert' => 'Hay :count item por debajo del inventario mínimo o próximo a bajar.|Hay are :count elementos por debajo del inventario mínimo o próximos a bajar.',
    'assets_warrantee_alert' => 'Hay :count asiento de licencia que expira en los próximos :threshold días. | Hay :count asientos de licencias que expiran en los próximos :threshold días.',
    'license_expiring_alert' => 'Hay :count licencia que expira en los próximos :threshold días. | Hay :count licencias que expiran en los próximos :threshold días.',
    'to_reset' => 'Para restaurar tu contraseña de :web, rellena este formulario:',
    'type' => 'Tipo',
    'upcoming-audits' => 'Hay :count activo que se está preparando para auditoría dentro de :threshold days.|Hay :count activos que se están preparando para auditoría en :threshold days.',
    'user' => 'User',
    'username' => 'Username',
    'welcome' => 'Bienvenido, :name',
    'welcome_to' => '¡Bienvenido a: web!',
    'your_credentials' => 'Tus credenciales de Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accesorio devuelto',
    'Asset_Checkin_Notification' => 'Activo devuelto',
    'License_Checkin_Notification' => 'Licencia devuelta',
    'Expected_Checkin_Report' => 'Informe de devolución de activo esperado',
    'Expected_Checkin_Notification' => 'Recordatorio: :name se acerca la fecha de devolución',
    'Expected_Checkin_Date' => 'Un activo asignado a ti debe ser devuelto en :date',
    'your_assets' => 'Ver tus activos'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/es-MX/mail.php <==
<?php

return [
    'a_user_canceled' => 'El usuario ha cancelado el item solicitado en la pagina Web',
    'a_user_requested' => 'Un usuario a solicitado un item en la pagina Web',
    'accessory_name' => 'Nombre de accesorio:',
    'additional_notes' => 'Notas adicionales:',
    'admin_has_created' => 'Un administrador ha creado una cuenta para ti en la web :web.',
    'asset' => 'Activo:',
    'asset_name' => 'Nombre del activo:',
    'asset_requested' => 'Activo solicitado',
    'asset_tag' => 'Etiqueta de activo',
    'assigned_to' => 'Asignado a',
    'best_regards' => 'Cordialmente,',
    'canceled' => 'Cancelado:',
    'checkin_date' => 'Fecha de entrada:',
    'checkout_date' => 'Fecha de salida:',
    'click_to_confirm' => 'Por favor, pulsa en el siguiente enlace para verificar tu cuenta de :web:',
    'click_on_the_link_accessory' => 'Haga clic en el enlace en la parte inferior para confirmar que ha recibido el accesorio.',
    'click_on_the_link_asset' => 'Haga clic en el enlace en la parte inferior para confirmar que ha recibido el activo.',
    'Confirm_Asset_Checkin' => 'Confirmar devolución del activo',
    'Confirm_Accessory_Checkin' => 'Confirmar devolución del accesorio',
    'Confirm_accessory_delivery' => 'Confirma entrega de accesorio',
    'Confirm_license_delivery' => 'Confirma entrega de licencia',
    'Confirm_asset_delivery' => 'Confirma entrega de activo',
    'Confirm_consumable_delivery' => 'Confirma entrega de consumible',
    'current_QTY' => 'Cantidad actual',
    'Days' => 'Días',
    'days' => 'Días',
    'expecting_checkin_date' => 'Fecha de devolución prevista:',
    'expires' => 'Expira',
    'Expiring_Assets_Report' => 'Informe de activos que expiran.',
    'Expiring_Licenses_Report' => 'Informe de licencias que expiran.',
    'hello' => 'Hola',
    'hi' => 'Hola',
    'i_have_read' => 'Ha leído y aceptado los términos de uso y he recibido este artículo.',
    'item' => 'Articulo:',
    'Item_Request_Canceled' => 'Solicitud de cancelación de requerimiento',
    'Item_Requested' => 'Artículo solicitado',
    'link_to_update_password' => 'Haga clic en el siguiente enlace para actualizar su: contraseña de la web:',
    'login_first_admin' => 'Inicie sesión en su nueva instalación de Snipe-IT con las credenciales siguientes:',
    'login' => 'Entrar:',
    'Low_Inventory_Report' => 'Reporte de inventario bajo',
    'min_QTY' => 'Cantidad mínima',
    'name' => 'Nombre',
    'new_item_checked' => 'Un nuevo artículo se ha extraído bajo su nombre, los detalles están a continuación.',
    'password' => 'Contraseña:',
    'password_reset' => 'Reiniciar la contraseña',

    'read_the_terms' => 'Por favor lea las condiciones de uso a continuación.',
    'read_the_terms_and_click' => 'Por favor lea los términos de uso abajo y haga clic en el enlace en la parte inferior para confirmar que leído y acepta los términos de uso y han recibido el activo.',
    'requested' => 'Solicitado:',
    'reset_link' => 'Tu enlace de restablecimiento de contraseña',
    'reset_password' => 'Haga Clic aquí para restablecer su contraseña:',
    'serial' => 'Serial',
    'supplier' => 'Proveedor',
    'tag' => 'Etiqueta',
    'test_email' => 'Email de prueba de Snipe-IT',
    'test_mail_text' => 'Esto es una prueba desde el sistema de gestión de activos de Snipe-IT. Si tienes esto, correo está funcionando :)',
    'the_following_item' => 'El siguiente artículo ha sido devuelto: ',
    'low_inventory_alert' => 'Hay :count item por debajo del inventario mínimo o próximo a bajar.|Hay are :count elementos por debajo del inventario mínimo o próximos a bajar.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'Hay :count licencia que expira en los próximos :threshold días. | Hay :count licencias que expiran en los próximos :threshold días.',
    'to_reset' => 'Para restaurar tu contraseña de :web, rellena este formulario:',
    'type' => 'Tipo',
    'upcoming-audits' => 'Hay :count activo que se está preparando para auditoría dentro de :threshold days.|Hay :count activos que se están preparando para auditoría en :threshold days.',
    'user' => 'User',
    'username' => 'Username',
    'welcome' => 'Bienvenido, :name',
    'welcome_to' => '¡Bienvenido a: web!',
    'your_credentials' => 'Tus credenciales de Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accesorio devuelto',
    'Asset_Checkin_Notification' => 'Activo devuelto',
    'License_Checkin_Notification' => 'Licencia devuelta',
    'Expected_Checkin_Report' => 'Informe de devolución de activo esperado',
    'Expected_Checkin_Notification' => 'Recordatorio: :name se acerca la fecha de devolución',
    'Expected_Checkin_Date' => 'Un activo asignado a ti debe ser devuelto en :date',
    'your_assets' => 'Ver tus activos',
];
